.. Berk documentation master file, created by
   sphinx-quickstart on Wed Aug 23 14:54:50 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Berk - a package for producing and managing MeerKAT continuum survey data
=========================================================================

.. include:: ../README.rst

.. toctree::
   :caption: Contents:

   install
   usage
   commands


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
